@@ -1236,10 +1236,10 @@ class Provider(DateTimeProvider):
                   'capital': 'Лондон'},
                  ]
 
-    def day_of_week(self):
+    def day_of_week(self) -> str:
         day = self.date('%w')
         return self.DAY_NAMES[day]
 
-    def month_name(self):
+    def month_name(self) -> str:
         month = self.month()
         return self.MONTH_NAMES[month]
