@@ -4,17 +4,20 @@ import sys
 import warnings
 
 from decimal import Decimal
+from typing import Any, Dict, Iterable, Iterator, List, Optional, Tuple, Union, no_type_check
 
-from .. import BaseProvider
+from .. import BaseProvider, ElementsType
+
+ValueTypes = Optional[Union[List[str], Tuple[str, ...]]]
 
 
 class Provider(BaseProvider):
-    default_value_types = (
+    default_value_types: ElementsType = (
         'str', 'str', 'str', 'str', 'float', 'int', 'int', 'decimal',
         'date_time', 'uri', 'email',
     )
 
-    def _check_signature(self, value_types, allowed_types):
+    def _check_signature(self, value_types: ValueTypes, allowed_types: Tuple[str]) -> Tuple[str, ...]:
         if value_types is not None and not isinstance(value_types, (list, tuple)):
             value_types = [value_types]
             warnings.warn(
@@ -185,22 +188,27 @@ class Provider(BaseProvider):
         if left_digits is None and right_digits is not None:
             left_digits = self.random_int(minimum_left_digits, max_random_digits)
 
-        sign = ''
         left_number = ''.join([str(self.random_digit()) for i in range(0, left_digits)]) or '0'
         if right_digits is not None:
             right_number = ''.join([str(self.random_digit()) for i in range(0, right_digits)])
         else:
             right_number = ''
-        sign = '+' if positive else self.random_element(('+', '-'))
+
+        if min_value is not None and min_value >= 0:
+            sign = '+'
+        elif max_value is not None and max_value <= 0:
+            sign = '-'
+        else:
+            sign = '+' if positive else self.random_element(('+', '-'))
 
         result = Decimal(f'{sign}{left_number}.{right_number}')
 
         # Because the random result might have the same number of decimals as max_value the random number
         # might be above max_value or below min_value
         if max_value is not None and result > max_value:
-            result = max_value
+            result = Decimal(max_value)
         if min_value is not None and result < min_value:
-            result = min_value
+            result = Decimal(min_value)
 
         return result
 
@@ -228,18 +236,19 @@ class Provider(BaseProvider):
                 value_types,
                 *allowed_types))
 
+    @no_type_check
     def pyiterable(
             self,
-            nb_elements=10,
-            variable_nb_elements=True,
-            value_types=None,
-            *allowed_types):
+            nb_elements: int = 10,
+            variable_nb_elements: bool = True,
+            value_types: ValueTypes = None,
+            *allowed_types: str) -> Iterable[Any]:
         value_types = self._check_signature(value_types, allowed_types)
         return self.random_element([self.pylist, self.pytuple, self.pyset])(
             nb_elements, variable_nb_elements, value_types, *allowed_types)
 
-    def _random_type(self, type_list):
-        value_type = self.random_element(type_list)
+    def _random_type(self, type_list: List[str]) -> str:
+        value_type: str = self.random_element(type_list)
 
         method_name = f'py{value_type}'
         if hasattr(self, method_name):
@@ -249,19 +258,19 @@ class Provider(BaseProvider):
 
     def _pyiterable(
             self,
-            nb_elements=10,
-            variable_nb_elements=True,
-            value_types=None,
-            *allowed_types):
+            nb_elements: int = 10,
+            variable_nb_elements: bool = True,
+            value_types: ValueTypes = None,
+            *allowed_types: str) -> Iterator:
 
-        value_types = self._check_signature(value_types, allowed_types)
+        value_types = self._check_signature(value_types, allowed_types)  # type: ignore
 
         value_types = [t if isinstance(t, str) else getattr(t, '__name__', type(t).__name__).lower()
                        for t in value_types
                        # avoid recursion
                        if t not in ['iterable', 'list', 'tuple', 'dict', 'set']]
         if not value_types:
-            value_types = self.default_value_types
+            value_types = self.default_value_types  # type: ignore
 
         if variable_nb_elements:
             nb_elements = self.randomize_nb_elements(nb_elements, min=1)
@@ -285,15 +294,15 @@ class Provider(BaseProvider):
             self._pyiterable(nb_elements, False, value_types, *allowed_types),
         ))
 
-    def pystruct(self, count=10, value_types=None, *allowed_types):
-        value_types = self._check_signature(value_types, allowed_types)
+    def pystruct(self, count: int = 10, value_types: ValueTypes = None, *allowed_types: str) -> Tuple[List, Dict, Dict]:
+        value_types = self._check_signature(value_types, allowed_types)  # type: ignore
 
         value_types = [t if isinstance(t, str) else getattr(t, '__name__', type(t).__name__).lower()
                        for t in value_types
                        # avoid recursion
                        if t != 'struct']
         if not value_types:
-            value_types = self.default_value_types
+            value_types = self.default_value_types  # type: ignore
 
         types = []
         d = {}
